@@ -41,7 +41,13 @@ anything.
 
 =cut
 
-sub _build_regex { qr{^\s* on \s+ (\w+)}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+
+sub regex { qr{^\s* on \s+ (\w+)}x }
 
 =head1 METHODS
 
@@ -70,7 +76,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { name => $_[1] }
+    return { name => $_[0] }
 }
 
 =head2 generate
