@@ -27,14 +27,29 @@ use Moose;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
-__PACKAGE__->create_children(qw/
-    Net::ISC::DHCPd::Config::Option
-    Net::ISC::DHCPd::Config::Filename
-    Net::ISC::DHCPd::Config::KeyValue
-/);
+=head2 children
+
+See L<Net::ISC::DHCPd::Config::Role/children>.
+
+=cut
+
+sub children {
+    return qw/
+        Net::ISC::DHCPd::Config::Host::FixedAddress
+        Net::ISC::DHCPd::Config::Host::HardwareEthernet
+        Net::ISC::DHCPd::Config::Option
+        Net::ISC::DHCPd::Config::Filename
+        Net::ISC::DHCPd::Config::KeyValue
+    /;
+}
+__PACKAGE__->create_children(__PACKAGE__->children());
 
 =head1 ATTRIBUTES
 
+=head2 fixedaddress
+
+Convienence method that wraps     shift->fixedaddresses->[0]
+
 =head2 options
 
 A list of parsed L<Net::ISC::DHCPd::Config::Option> objects.
@@ -52,6 +67,31 @@ before add_filename => sub {
     }
 };
 
+before add_fixedaddress => sub {
+    if(0 < int @{ $_[0]->fixedaddresses }) {
+        confess 'Host cannot have more than one ip address';
+    }
+};
+
+before add_hardwareethernet => sub {
+    if(0 < int @{ $_[0]->hardwareethernets }) {
+        confess 'Host cannot have more than one mac address';
+    }
+};
+
+sub fixedaddress {
+    shift->fixedaddresses->[0];
+}
+
+=head2 hardwareethernet
+
+Convienence method that wraps shift->hardwareethernets->[0]
+
+=cut
+sub hardwareethernet {
+    shift->hardwareethernets->[0];
+}
+
 =head2 keyvalues
 
 A list of parsed L<Net::ISC::DHCPd::Config::KeyValue> objects.
@@ -67,7 +107,13 @@ has name => (
     isa => 'Str',
 );
 
-sub _build_regex { qr{^ \s* host \s+ (\S+)}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+
+sub regex { qr{^ \s* host \s+ (\S+)}x }
 
 =head1 METHODS
 
@@ -78,7 +124,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { name => $_[1] };
+    return { name => $_[0] };
 }
 
 =head2 generate
