@@ -36,7 +36,12 @@ has name => (
     isa => 'Str',
 );
 
-sub _build_regex { qr{^\s* option \s+ space \s+ (.*) ;}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+sub regex { qr{^\s* option \s+ space \s+ (.*) ;}x }
 
 =head1 METHODS
 
@@ -47,7 +52,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { name => $_[1] }
+    return { name => $_[0] }
 }
 
 =head2 generate
