@@ -27,13 +27,21 @@ use Moose;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
-__PACKAGE__->create_children(qw/
-    Net::ISC::DHCPd::Config::Host
-    Net::ISC::DHCPd::Config::Option
-    Net::ISC::DHCPd::Config::Range
-    Net::ISC::DHCPd::Config::Range6
-    Net::ISC::DHCPd::Config::KeyValue
-/);
+=head2 children
+
+See L<Net::ISC::DHCPd::Config::Role/children>.
+
+=cut
+sub children {
+    return qw/
+        Net::ISC::DHCPd::Config::Host
+        Net::ISC::DHCPd::Config::Option
+        Net::ISC::DHCPd::Config::Range
+        Net::ISC::DHCPd::Config::Range6
+        Net::ISC::DHCPd::Config::KeyValue
+    /;
+}
+__PACKAGE__->create_children(__PACKAGE__->children());
 
 =head1 ATTRIBUTES
 
@@ -47,7 +55,12 @@ A list of parsed L<Net::ISC::DHCPd::Config::Range> objects.
 
 =cut
 
-sub _build_regex { qr{^ \s* pool}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+sub regex { qr{^ \s* pool}x }
 
 =head1 METHODS
 
